@@ -120,10 +120,12 @@ class DesaturationsMeasures:
 
             # Due to mislabeling, the max value may be after the min value, in which case ignore the desaturation.
             if len(desaturation_idx_max_min) > 0:
-                p = np.polyfit(np.int64(desaturation_time[desaturation_idx_max_min]),
+                try:
+                    p = np.polyfit(np.int64(desaturation_time[desaturation_idx_max_min]),
                                desaturation_spo2[desaturation_idx_max_min], 1)
-
-                desaturation_slope_all[i] = p[0]
+                    desaturation_slope_all[i] = p[0]
+                except:
+                    desaturation_slope_all[i] = np.nan
 
         diff_desats = abs(starts - np.roll(starts, 1))
         diff_desats = diff_desats[1:]
